(function ($) {

  /**
   * Generates charts and map to each GPX field element.
   */
  Drupal.behaviors.GPX = {
    attach: function (context, settings) {
      // Level chart (level diagram).
      $.each(settings.gpxField.gpxFieldLevelCharts, function(index, value) {
        var $element = $('#' + value.element);
        $element.once('gpx-generated', function() {
          value.settings.xAxis.labels = {
            // Show only first and last label.
            formatter: function() {
              if (this.isFirst || this.isLast) {
                return this.value;
              }
              else {
                return null;
              }
            }
          };
          $element.highcharts(value.settings);
        });
      });

      // Difficulty chart (levels).
      $.each(settings.gpxField.gpxFieldDifficultyCharts, function(index, value) {
        var $element = $('#' + value.element);
        $element.once('gpx-generated', function() {
          $element.highcharts(value.settings);
        });
      });

      // Show coordinates in google map.
      $.each(settings.gpxField.gpxMaps, function(index, map) {
        var $element = $('#' + map.element);
        $element.once('gpx-generated', function() {
          var coordinates = [];
          var startpoint = new google.maps.LatLng(0, 0);

          // Get the coordinate points.
          $.each(map.points, function(i, point) {
            if (i == 0) {
              startpoint = new google.maps.LatLng(point.lat, point.lon);
            }
            coordinates.push(new google.maps.LatLng(point.lat, point.lon));
          });

          var options = {
            zoom: 10,
            center: startpoint,
            mapTypeId: google.maps.MapTypeId.TERRAIN
          };
          // Google maps doesn't generate the map if I use $element dom elem.
          var map = new google.maps.Map(document.getElementById(map.element), options);
          var polyline = new google.maps.Polyline({
            path: coordinates,
            strokeColor: '#FF0000',
            strokeOpacity: 1.0,
            strokeWeight: 2
          });

          polyline.setMap(map);
        });
      });
    }
  };
})(jQuery);
